@@ -21,8 +21,14 @@ class PermissionPolicy(RecordPermissionPolicy):
     can_delete_draft = [AnyUser()]
     can_publish = [AnyUser()]
     can_create_files = [AnyUser()]
+    can_set_content_files = [AnyUser()]
+    can_get_content_files = [AnyUser()]
+    can_commit_files = [AnyUser()]
     can_read_files = [AnyUser()]
     can_update_files = [AnyUser()]
     can_draft_create_files = [AnyUser()]
+    can_draft_set_content_files = [AnyUser()]
+    can_draft_get_content_files = [AnyUser()]
+    can_draft_commit_files = [AnyUser()]
     can_draft_read_files = [AnyUser()]
     can_draft_update_files = [AnyUser()]
